import { useState, useEffect } from 'react';
import { useQuery } from '@tanstack/react-query';
// Import team meeting image
import teamMeetingImage from '../assets/team_meeting.jpg';
import FiltersSection from '@/components/FiltersSection';
import ActiveFilters from '@/components/ActiveFilters';
import CategorySection from '@/components/CategorySection';
import CourseCard from '@/components/CourseCard';
import GovResourceCard from '@/components/GovResourceCard';
import Newsletter from '@/components/Newsletter';
import Pagination from '@/components/Pagination';
import { CATEGORY_LABELS } from '@/lib/constants';
import { useFilters } from '@/contexts/FilterContext';

// Import types from schema
import { Resource, Course } from '@shared/schema';

// Define response types for better type safety
interface PaginationInfo {
  total: number;
  page: number;
  limit: number;
  totalPages: number;
}

interface CoursesResponse {
  courses: Course[];
  pagination: PaginationInfo;
}

export default function Home() {
  const { categoryFilter, stateFilter, modeFilters, searchQuery, setCategoryFilter } = useFilters();

  // State for pagination
  const [currentPage, setCurrentPage] = useState(1);
  const [pageSize, setPageSize] = useState(12); // Default page size
  
  // Reset to page 1 when filters change
  useEffect(() => {
    setCurrentPage(1);
  }, [categoryFilter, stateFilter, modeFilters, searchQuery]);
  
  // Check if a specific category filter is active OR search is being used
  const isSearchActive = Boolean(searchQuery && searchQuery.trim() !== '');
  const isCategoryFilterActive = Boolean(categoryFilter && categoryFilter !== 'all') || isSearchActive;
  
  // Fetch all categories with their courses (for home page display)
  const { data: groupedCoursesData, isLoading: isLoadingGrouped } = useQuery<Record<string, Course[]>>({
    queryKey: [
      '/api/courses/grouped',
      stateFilter,
      modeFilters.join(','),
    ],
    // Always run this query by default - we want to show courses on the homepage
    // regardless of login status
    refetchOnMount: true,
    refetchOnWindowFocus: true,
    staleTime: 0,
    queryFn: async () => {
      const params = new URLSearchParams();
      if (stateFilter && stateFilter !== 'all') params.append('state', stateFilter);
      
      // Always append all mode filters for the default view
      if (modeFilters.length === 0) {
        // If somehow modeFilters is empty, add all modes
        params.append('mode', 'online');
        params.append('mode', 'in-person');
        params.append('mode', 'hybrid');
      } else {
        modeFilters.forEach(mode => params.append('mode', mode));
      }
      params.append('minPerCategory', '4'); 
      
      const url = `/api/courses/grouped?${params.toString()}`;
      console.log('Fetching grouped courses with URL:', url);
      const response = await fetch(url);
      if (!response.ok) {
        throw new Error('Failed to fetch courses');
      }
      return response.json();
    }
  });
  
  // Fetch courses for a specific category or search query
  const { data: categoryData, isLoading: isLoadingCategory } = useQuery<CoursesResponse>({
    queryKey: [
      '/api/courses', 
      categoryFilter,
      stateFilter,
      modeFilters.join(','),
      searchQuery,
      currentPage,
      pageSize
    ],
    // Run this query when a specific category is selected OR when search is being used
    enabled: isCategoryFilterActive || isSearchActive,
    queryFn: async () => {
      const params = new URLSearchParams();
      if (categoryFilter && categoryFilter !== 'all') params.append('category', categoryFilter);
      if (stateFilter && stateFilter !== 'all') params.append('state', stateFilter);
      modeFilters.forEach(mode => params.append('mode', mode));
      if (searchQuery) params.append('search', searchQuery);
      // Use standard pagination for all categories
      params.append('page', currentPage.toString());
      params.append('limit', pageSize.toString());
      
      const url = `/api/courses?${params.toString()}`;
      console.log(`Fetching ${isSearchActive ? 'search results' : 'specific category'}: ${searchQuery || categoryFilter} with URL: ${url}`);
      const response = await fetch(url);
      return response.json();
    }
  });
  
  // Fetch government resources (always shown)
  const { data: resources, isLoading: isLoadingResources } = useQuery<Resource[]>({
    queryKey: ['/api/resources'],
  });

  // Determine if we're in a loading state
  const isLoading = isCategoryFilterActive ? isLoadingCategory : isLoadingGrouped;
  
  // Log current filter state
  console.log(`Filter active: ${isCategoryFilterActive}, category: ${categoryFilter}, state: ${stateFilter}`);
  
  // Prepare the data for display
  const categoryCourses = categoryData?.courses || [];
  const pagination = categoryData?.pagination;
  
  // Create a properly structured coursesByCategory object based on active filters
  const coursesByCategory = isCategoryFilterActive 
    ? { [categoryFilter]: categoryCourses }  // When showing a specific category
    : (groupedCoursesData || {});           // When showing all categories
    
  // Debug log the number of categories found
  if (coursesByCategory && Object.keys(coursesByCategory).length > 0) {
    console.log("Found categories:", Object.keys(coursesByCategory).length);
    console.log("First category:", Object.keys(coursesByCategory)[0], "has", coursesByCategory[Object.keys(coursesByCategory)[0]]?.length || 0, "courses");
  } else {
    console.log("No categories found in coursesByCategory");
  }

  return (
    <>
      <section className="relative bg-gradient-to-r from-primary to-blue-700 text-white py-16">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="md:flex md:items-center md:justify-between">
            <div className="md:w-1/2 mb-8 md:mb-0">
              <h1 className="text-3xl md:text-4xl font-bold mb-4">Discover the skills that open doors</h1>
              <p className="text-lg md:text-xl mb-6 opacity-90">Browse thousands of courses tailored for career advancement or complete transformation—all in one place!</p>
              <div className="flex flex-wrap gap-3 mb-6">
                <span className="inline-flex items-center px-3 py-1 rounded-full text-sm font-medium bg-blue-600 text-white shadow-sm">
                  <i className="ri-computer-line mr-1"></i> Online Courses
                </span>
                <span className="inline-flex items-center px-3 py-1 rounded-full text-sm font-medium bg-green-600 text-white shadow-sm">
                  <i className="ri-building-2-line mr-1"></i> In-Person Training
                </span>
                <span className="inline-flex items-center px-3 py-1 rounded-full text-sm font-medium bg-purple-600 text-white shadow-sm">
                  <i className="ri-government-line mr-1"></i> Government Resources
                </span>
              </div>
              
              <div className="bg-white bg-opacity-20 p-4 rounded-lg shadow-sm border border-white border-opacity-30 backdrop-blur-sm">
                <h3 className="text-lg font-semibold mb-2 flex items-center">
                  <span className="mr-2">✨</span> New! Personalized Skills Finder
                </h3>
                <p className="text-sm mb-3">Take our interactive quiz to get custom course recommendations based on your career goals, location, and learning preferences.</p>
                <a 
                  href="/skills-finder" 
                  className="inline-flex items-center px-4 py-2 bg-white text-primary rounded-md text-sm font-medium shadow-sm hover:bg-opacity-90 transition-colors"
                >
                  Find Your Perfect Courses
                  <svg xmlns="http://www.w3.org/2000/svg" className="h-4 w-4 ml-2" viewBox="0 0 20 20" fill="currentColor">
                    <path fillRule="evenodd" d="M12.293 5.293a1 1 0 011.414 0l4 4a1 1 0 010 1.414l-4 4a1 1 0 01-1.414-1.414L14.586 11H3a1 1 0 110-2h11.586l-2.293-2.293a1 1 0 010-1.414z" clipRule="evenodd" />
                  </svg>
                </a>
              </div>
            </div>
            <div className="md:w-1/2 flex justify-center">
              <img 
                src={teamMeetingImage} 
                alt="Team discussing skills training and development" 
                className="rounded-lg shadow-lg max-h-80 object-cover"
                style={{ objectPosition: '0 30%' }}
                width="450"
                height="450"
              />
            </div>
          </div>
        </div>
        <div className="absolute bottom-0 w-full h-16 bg-white" style={{ clipPath: 'polygon(0 100%, 100% 100%, 100% 0, 0 100%)' }}></div>
      </section>

      {/* Filters Section */}
      <FiltersSection />

      {/* Course Directory */}
      <main className="py-8 max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        {/* Active Filters */}
        <ActiveFilters />

        {/* Display courses by category */}
        {isLoading ? (
          <div className="flex justify-center items-center py-12">
            <div className="animate-spin rounded-full h-12 w-12 border-b-2 border-primary"></div>
          </div>
        ) : (
          <>
            {/* If we have search results, display them in their own section */}
            {isSearchActive ? (
              <div>
                <h2 className="text-2xl font-bold text-slate-800 mb-6">
                  Search Results for "{searchQuery}"
                </h2>
                {categoryCourses.length > 0 ? (
                  <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6 mb-12">
                    {categoryCourses.map(course => (
                      <div key={course.id} className="course-card">
                        {/* Use CourseCard component directly here */}
                        <CourseCard course={course} />
                      </div>
                    ))}
                  </div>
                ) : (
                  <div className="text-center py-8 mb-6">
                    <h3 className="text-xl font-semibold text-gray-600">No courses match your search query</h3>
                    <p className="text-gray-500 mt-2">Try adjusting your search terms or filters</p>
                  </div>
                )}
              </div>
            ) : categoryFilter && categoryFilter !== 'all' ? (
              // If we have a category filter, only show that category
              <CategorySection 
                title={CATEGORY_LABELS[categoryFilter] || categoryFilter}
                courses={categoryCourses}
                category={categoryFilter} 
              />
            ) : (
              // Otherwise show all categories
              Object.entries(coursesByCategory).map(([category, courses]) => (
                <CategorySection 
                  key={category} 
                  title={CATEGORY_LABELS[category] || category}
                  courses={courses}
                  category={category}
                />
              ))
            )}

            {/* If no courses match the filters - only show when not searching */}
            {!isSearchActive && (isCategoryFilterActive ? categoryCourses.length === 0 : Object.keys(coursesByCategory).length === 0) && (
              <div className="text-center py-12">
                <h3 className="text-xl font-semibold text-gray-600">No courses match your filters</h3>
                <p className="text-gray-500 mt-2">Try adjusting your search criteria</p>
              </div>
            )}
            
            {/* Pagination */}
            {pagination && pagination.totalPages > 1 && (
              <Pagination 
                currentPage={pagination.page} 
                totalPages={pagination.totalPages} 
                onPageChange={setCurrentPage}
              />
            )}
          </>
        )}

        {/* Skills Finder Promotion Section - show when no category is selected and no search is active */}
        {(!categoryFilter || categoryFilter === 'all') && !isSearchActive && (
          <section className="mb-12 rounded-xl overflow-hidden shadow-md border border-slate-200">
            <div className="grid md:grid-cols-2 bg-gradient-to-r from-primary to-blue-600">
              <div className="p-8 text-white">
                <h2 className="text-2xl font-bold mb-4 flex items-center">
                  <svg xmlns="http://www.w3.org/2000/svg" className="h-6 w-6 mr-3" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                    <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M9.663 17h4.673M12 3v1m6.364 1.636l-.707.707M21 12h-1M4 12H3m3.343-5.657l-.707-.707m2.828 9.9a5 5 0 117.072 0l-.548.547A3.374 3.374 0 0014 18.469V19a2 2 0 11-4 0v-.531c0-.895-.356-1.754-.988-2.386l-.548-.547z" />
                  </svg>
                  Personalized Skills Finder
                </h2>
                <p className="mb-6 opacity-90">Not sure where to start? Get personalized course recommendations based on your:</p>
                <ul className="mb-6 space-y-2">
                  <li className="flex items-center">
                    <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5 mr-2 text-green-300" viewBox="0 0 20 20" fill="currentColor">
                      <path fillRule="evenodd" d="M16.707 5.293a1 1 0 010 1.414l-8 8a1 1 0 01-1.414 0l-4-4a1 1 0 011.414-1.414L8 12.586l7.293-7.293a1 1 0 011.414 0z" clipRule="evenodd" />
                    </svg>
                    Location and preferred learning format
                  </li>
                  <li className="flex items-center">
                    <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5 mr-2 text-green-300" viewBox="0 0 20 20" fill="currentColor">
                      <path fillRule="evenodd" d="M16.707 5.293a1 1 0 010 1.414l-8 8a1 1 0 01-1.414 0l-4-4a1 1 0 011.414-1.414L8 12.586l7.293-7.293a1 1 0 011.414 0z" clipRule="evenodd" />
                    </svg>
                    Career goals and aspirations
                  </li>
                  <li className="flex items-center">
                    <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5 mr-2 text-green-300" viewBox="0 0 20 20" fill="currentColor">
                      <path fillRule="evenodd" d="M16.707 5.293a1 1 0 010 1.414l-8 8a1 1 0 01-1.414 0l-4-4a1 1 0 011.414-1.414L8 12.586l7.293-7.293a1 1 0 011.414 0z" clipRule="evenodd" />
                    </svg>
                    Current skill level and experience
                  </li>
                  <li className="flex items-center">
                    <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5 mr-2 text-green-300" viewBox="0 0 20 20" fill="currentColor">
                      <path fillRule="evenodd" d="M16.707 5.293a1 1 0 010 1.414l-8 8a1 1 0 01-1.414 0l-4-4a1 1 0 011.414-1.414L8 12.586l7.293-7.293a1 1 0 011.414 0z" clipRule="evenodd" />
                    </svg>
                    Available time commitment
                  </li>
                </ul>
                <a 
                  href="/skills-finder" 
                  className="inline-flex items-center px-5 py-2.5 bg-white text-primary rounded-md text-sm font-medium shadow-sm hover:bg-opacity-90 transition-colors"
                >
                  Take the Quiz
                  <svg xmlns="http://www.w3.org/2000/svg" className="h-4 w-4 ml-2" viewBox="0 0 20 20" fill="currentColor">
                    <path fillRule="evenodd" d="M12.293 5.293a1 1 0 011.414 0l4 4a1 1 0 010 1.414l-4 4a1 1 0 01-1.414-1.414L14.586 11H3a1 1 0 110-2h11.586l-2.293-2.293a1 1 0 010-1.414z" clipRule="evenodd" />
                  </svg>
                </a>
              </div>
              <div className="bg-blue-50 flex items-center justify-center p-6">
                <img 
                  src="/images/category/technology-small.webp"
                  alt="Personalized Learning Path" 
                  className="rounded-lg shadow-lg max-h-80 object-cover"
                  width="300"
                  height="200"
                />
              </div>
            </div>
          </section>
        )}

        {/* Government Resources Section - Only show when no category is selected and no search is active */}
        {(!categoryFilter || categoryFilter === 'all') && !isSearchActive && (
          <section className="mb-12 bg-slate-50 rounded-xl p-6 border border-slate-200">
            <div className="flex items-center justify-between mb-4">
              <h2 className="text-2xl font-bold text-slate-800">Government & State Resources</h2>
              <button 
                onClick={() => setCategoryFilter('Government & State Resources')}
                className="text-primary hover:text-primary/80 text-sm font-medium"
              >
                View All <i className="ri-arrow-right-line"></i>
              </button>
            </div>
            
            <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
              {isLoadingResources ? (
                <div className="flex justify-center items-center py-8 col-span-3">
                  <div className="animate-spin rounded-full h-8 w-8 border-b-2 border-primary"></div>
                </div>
              ) : (
                resources?.map(resource => (
                  <GovResourceCard key={resource.id} resource={resource} />
                ))
              )}
            </div>
          </section>
        )}

        {/* Newsletter Signup */}
        <Newsletter />
      </main>

    </>
  );
}
